======================================
Welcome to oslo.utils's documentation!
======================================

The `oslo`_ utils library provides support for common utility type functions,
such as encoding, exception handling, string manipulation, and time handling.

.. toctree::
   :maxdepth: 1

   installation
   usage
   contributing

API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/dictutils
   api/encodeutils
   api/eventletutils
   api/excutils
   api/fileutils
   api/fixture
   api/fnmatch
   api/imageutils
   api/importutils
   api/netutils
   api/reflection
   api/secretutils
   api/specs_matcher
   api/strutils
   api/timeutils
   api/units
   api/uuidutils
   api/versionutils

Examples
========

.. toctree::
   :maxdepth: 2

   examples/timeutils

Release Notes
=============

.. toctree::
   :maxdepth: 1

   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _oslo: https://wiki.openstack.org/wiki/Oslo
